pub struct ValidationReport { /* private fields */ }Expand description
Complete validation report
Implementations
Sourceimpl ValidationReport
impl ValidationReport
pub fn marks(&self) -> &[ProvenanceMark]
pub fn chains(&self) -> &[ChainReport]
Sourcepub fn format(&self, format: ValidationReportFormat) -> String
pub fn format(&self, format: ValidationReportFormat) -> String
Format the validation report as human-readable text.
Returns a formatted string if the report contains interesting information (issues, multiple chains, or multiple sequences). Returns an empty string if the report represents a single perfect chain with no issues.
Sourcepub fn has_issues(&self) -> bool
pub fn has_issues(&self) -> bool
Check if the validation report has any issues.
Returns true if there are validation issues, missing genesis, multiple chains, or multiple sequences.
Sourcepub fn validate(marks: Vec<ProvenanceMark>) -> Self
pub fn validate(marks: Vec<ProvenanceMark>) -> Self
Validate a collection of provenance marks Validate a collection of provenance marks