#[repr(u8)]pub enum ProvenanceMarkResolution {
Low = 0,
Medium = 1,
Quartile = 2,
High = 3,
}Variants
Implementations
Sourceimpl ProvenanceMarkResolution
impl ProvenanceMarkResolution
pub fn link_length(&self) -> usize
pub fn seq_bytes_length(&self) -> usize
pub fn date_bytes_length(&self) -> usize
pub fn fixed_length(&self) -> usize
pub fn key_range(&self) -> Range<usize>
pub fn chain_id_range(&self) -> Range<usize>
pub fn hash_range(&self) -> Range<usize>
pub fn seq_bytes_range(&self) -> Range<usize>
pub fn date_bytes_range(&self) -> Range<usize>
pub fn info_range(&self) -> RangeFrom<usize>
Sourcepub fn serialize_date(&self, date: Date) -> Result<Vec<u8>>
pub fn serialize_date(&self, date: Date) -> Result<Vec<u8>>
Serializes a Date into bytes based on the resolution.
Sourcepub fn deserialize_date(&self, data: &[u8]) -> Result<Date>
pub fn deserialize_date(&self, data: &[u8]) -> Result<Date>
Deserializes bytes into a Date based on the resolution.
Sourcepub fn serialize_seq(&self, seq: u32) -> Result<Vec<u8>>
pub fn serialize_seq(&self, seq: u32) -> Result<Vec<u8>>
Serializes a sequence number into bytes based on the resolution.
Sourcepub fn deserialize_seq(&self, data: &[u8]) -> Result<u32>
pub fn deserialize_seq(&self, data: &[u8]) -> Result<u32>
Deserializes bytes into a sequence number based on the resolution.