pub struct ProvenanceMark { /* private fields */ }Implementations
Sourceimpl ProvenanceMark
impl ProvenanceMark
Sourcepub fn validate(marks: Vec<ProvenanceMark>) -> ValidationReport
pub fn validate(marks: Vec<ProvenanceMark>) -> ValidationReport
Validate a collection of provenance marks
This method analyzes the provided marks and produces a comprehensive validation report that includes:
- Deduplication of exact duplicates
- Organization by chain ID
- Detection of genesis marks
- Identification of contiguous sequences
- Flagging of validation issues (hash mismatches, sequence gaps, etc.)
Sourceimpl ProvenanceMark
impl ProvenanceMark
pub fn res(&self) -> ProvenanceMarkResolution
pub fn key(&self) -> &[u8] ⓘ
pub fn hash(&self) -> &[u8] ⓘ
pub fn chain_id(&self) -> &[u8] ⓘ
pub fn seq_bytes(&self) -> &[u8] ⓘ
pub fn date_bytes(&self) -> &[u8] ⓘ
pub fn seq(&self) -> u32
pub fn date(&self) -> Date
pub fn message(&self) -> Vec<u8> ⓘ
pub fn info(&self) -> Option<CBOR>
Sourceimpl ProvenanceMark
impl ProvenanceMark
pub fn new( res: ProvenanceMarkResolution, key: Vec<u8>, next_key: Vec<u8>, chain_id: Vec<u8>, seq: u32, date: Date, info: Option<impl CBOREncodable>, ) -> Result<Self>
pub fn from_message( res: ProvenanceMarkResolution, message: Vec<u8>, ) -> Result<Self>
Sourceimpl ProvenanceMark
impl ProvenanceMark
Sourcepub fn identifier(&self) -> String
pub fn identifier(&self) -> String
The first four bytes of the mark’s hash as a hex string.
Sourcepub fn bytewords_identifier(&self, prefix: bool) -> String
pub fn bytewords_identifier(&self, prefix: bool) -> String
The first four bytes of the mark’s hash as upper-case ByteWords.
Sourcepub fn bytemoji_identifier(&self, prefix: bool) -> String
pub fn bytemoji_identifier(&self, prefix: bool) -> String
The first four bytes of the mark’s hash as Bytemoji.
Sourcepub fn bytewords_minimal_identifier(&self, prefix: bool) -> String
pub fn bytewords_minimal_identifier(&self, prefix: bool) -> String
A compact 8-letter identifier derived from the upper-case ByteWords identifier by taking the first and last letter of each ByteWords word (4 words × 2 letters = 8 letters).
Sourceimpl ProvenanceMark
impl ProvenanceMark
pub fn precedes(&self, next: &ProvenanceMark) -> bool
pub fn precedes_opt(&self, next: &ProvenanceMark) -> Result<()>
pub fn is_sequence_valid(marks: &[ProvenanceMark]) -> bool
pub fn is_genesis(&self) -> bool
Sourceimpl ProvenanceMark
impl ProvenanceMark
pub fn to_bytewords_with_style(&self, style: Style) -> String
pub fn to_bytewords(&self) -> String
pub fn from_bytewords( res: ProvenanceMarkResolution, bytewords: &str, ) -> Result<Self>
Sourceimpl ProvenanceMark
impl ProvenanceMark
pub fn to_url_encoding(&self) -> String
pub fn from_url_encoding(url_encoding: &str) -> Result<Self>
Sourceimpl ProvenanceMark
impl ProvenanceMark
pub fn fingerprint(&self) -> [u8; 32]